AuthProvider<TUser> class abstract

Adapter interface used by ConvexClient.withAuth for external auth systems.

Constructors

AuthProvider()
Creates an auth provider.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

extractIdToken(TUser authResult) String
Extracts the Convex ID token from an auth result.
login({required void onIdToken(String? token)}) Future<TUser>
Performs an interactive login flow and reports token updates through onIdToken.
loginFromCache({required void onIdToken(String? token)}) Future<TUser>
Restores a cached session and reports token updates through onIdToken.
logout() Future<void>
Logs out the current user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited